@@ -8,8 +8,8 @@ from mock import MagicMock, Mock
 from catkin_pkg.package_templates import _safe_write_files, create_package_files, \
     create_cmakelists, create_package_xml, PackageTemplate, _create_include_macro, \
     _create_targetlib_args
-from catkin_pkg.package import parse_package_for_distutils, parse_package, \
-    Dependency, Export, Url, PACKAGE_MANIFEST_FILENAME
+from catkin_pkg.package import parse_package, Dependency, Export, Url, PACKAGE_MANIFEST_FILENAME
+from catkin_pkg.python_setup import generate_distutils_setup
 
 
 class TemplateTest(unittest.TestCase):
@@ -172,7 +172,7 @@ class TemplateTest(unittest.TestCase):
             self.assertEqual(pack.replaces, pack_result.replaces)
             self.assertEqual(pack.exports, pack_result.exports)
 
-            rdict = parse_package_for_distutils(file2)
+            rdict = generate_distutils_setup(package_xml_path=file2)
             self.assertEqual({'name': 'bar',
                               'maintainer': u'John Foo',
                               'maintainer_email': 'foo@bar.com',
@@ -180,8 +180,7 @@ class TemplateTest(unittest.TestCase):
                               'license': 'BSD',
                               'version': '0.0.0',
                               'author': '',
-                              'url': 'foo',
-                              'keywords': ['ROS']}, rdict)
+                              'url': 'foo'}, rdict)
         finally:
             shutil.rmtree(rootdir)
 
@@ -257,14 +256,13 @@ class TemplateTest(unittest.TestCase):
             self.assertEqual(pack.exports[0].tagname, pack_result.exports[0].tagname)
             self.assertEqual(pack.exports[1].tagname, pack_result.exports[1].tagname)
 
-            rdict = parse_package_for_distutils(file2)
+            rdict = generate_distutils_setup(package_xml_path=file2)
             self.assertEqual({'name': 'bar',
                               'maintainer': u'John Foo <foo@bar.com>, John Foo <foo@bar.com>',
                               'description': 'pdesc',
                               'license': 'BSD, MIT',
                               'version': '0.0.0',
                               'author': u'John Foo <foo@bar.com>, John Foo <foo@bar.com>',
-                              'url': 'bar',
-                              'keywords': ['ROS']}, rdict)
+                              'url': 'bar'}, rdict)
         finally:
             shutil.rmtree(rootdir)
